function figures_paper(figdata_name)
load(figdata_name)

thick = 1.6;
thin = 1;

intep = 'tex';
font = 'times';
weight = 'normal';

% Figure 2
figure(2)
% y1 = plot(fig2.x(:,1),fig2.y(:,1)*100,'linewidth',thick,'Color',[0,0,0]);
y2 = plot(fig2.x(:,2),fig2.y(:,2)*100,'linestyle','-','linewidth',thick,'Color',[0,0,0]);
hold on
y3 = plot(fig2.x(:,3),fig2.y(:,3)*100,'linestyle','-','linewidth',thick,'Color',[0,0,0]+0.65);
hold off
axis([-1 10 -52 0])
legend1 = legend([y2,y3],'Cond. on expansion','Cond. on recession');
set(legend1,'fontname',font,'interpreter',intep,'Location','northeast','FontSize',8)
set(gca,'FontSize',8,'fontname',font)
xlabel('Duration of unemployment spell (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Perc. change','FontSize',10,'interpreter',intep,'fontname',font)
% title('Consumption level during unemployment spells','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure2.pdf

% Figure 3
figure(3)
h=bar(fig3.x,fig3.y,'hist');
set(h(1),'FaceColor',[0,0,0]);
set(h(2),'FaceColor',[0,0,0]+0.7);
xlim([0,20.5])
legend([h(1),h(2)],'Cond. on expansion','Cond. on recession')
set(legend,'fontname',font,'interpreter',intep,'Location','northeast','FontSize',8)
set(gca,'FontSize',8,'fontname',font)
xlabel('Duration of unemployment spell (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Frequency','FontSize',10,'interpreter',intep,'fontname',font)
% title('Distribution of unemployment duration','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure3.pdf

% Figure 4
figure(4)
y1 = plot(fig4.newx,fig4.newy,'color',[0,0,0],'LineWidth',thick);
grid on
set(gca,'FontSize',8,'fontname',font)
xlabel('Value of assets relative to average net-income loss','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Cumulative distribution','FontSize',10,'interpreter',intep,'fontname',font)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure4.pdf

% Figure 5
figure(5)
y1 = plot(fig5.x1,fig5.y1*100,'.','Color',[0,0,0],'markersize',11);
hold on
y2 = plot(fig5.x2,fig5.y2*100,'.','Color',[0,0,0]+0.65,'markersize',11);
ylim([-40,0])
xlim([0,max([fig5.x1(:);fig5.x2(:)])*1.1])
l = line(mean(fig5.x1)*[1,1],ylim,'Color',[0,0,0],'LineStyle','--','linewidth',1.2);
uistack(l,'bottom')
text(mean(fig5.x1),0.95*min(ylim)+0.05*max(ylim),'Mean','Color',[0,0,0],'BackgroundColor','white','HorizontalAlignment','center','interpreter',intep,'fontname',font,'fontsize',8)
l = line(mean(fig5.x2)*[1,1],ylim,'Color',[0,0,0]+0.5,'LineStyle','--','linewidth',1.2);
uistack(l,'bottom')
text(mean(fig5.x2),0.95*min(ylim)+0.05*max(ylim),'Mean','Color',[0,0,0]+0.5,'BackgroundColor','white','HorizontalAlignment','center','interpreter',intep,'fontname',font,'fontsize',8)
set(gca,'FontSize',8,'fontname',font)
xlabel('Real cash on hand','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Perc. change','FontSize',10,'interpreter',intep,'fontname',font)
legend([y1,y2],'Expansion','Recession')
set(legend,'fontname',font,'interpreter',intep,'Location','northwest','FontSize',8)


xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure5.pdf

% Figure 6
figure(6)
y1a = plot(fig6.x1,fig6.y1,'.','Color',[0,0,0],'markersize',11); % boom and employed
hold on
y1b = plot(fig6.x2,fig6.y2,'x','Color',[0,0,0],'markersize',3); % boom and unemployed
y2a = plot(fig6.x3,fig6.y3,'.','Color',[0,0,0]+0.65,'markersize',11); % boom and employed
y2b = plot(fig6.x4,fig6.y4,'x','Color',[0,0,0]+0.65,'markersize',3); % boom and unemployed
set(gca,'FontSize',8,'fontname',font)
xlabel('Total amount invested','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Share','FontSize',10,'interpreter',intep,'fontname',font)
legend([y1a,y1b,y2a,y2b],'Employed in expansion','Unemployed in expansion','Employed in recession','Unemployed in recession')
set(legend,'fontname',font,'interpreter',intep,'Position',[0.68,0.78,0.05,0.05],'FontSize',8)
axis([0 2 0 1.03])
xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure6.pdf

% Figure 7
figure(7)
y1a = plot(fig7.x1,fig7.y1,'.','Color',[0,0,0],'markersize',11); % boom and employed
hold on
y1b = plot(fig7.x2,fig7.y2,'x','Color',[0,0,0],'markersize',3); % boom and unemployed
y2a = plot(fig7.x3,fig7.y3,'.','Color',[0,0,0]+0.65,'markersize',11); % boom and employed
y2b = plot(fig7.x4,fig7.y4,'x','Color',[0,0,0]+0.65,'markersize',3); % boom and unemployed

set(gca,'FontSize',8,'fontname',font)
xlabel('Real cash on hand','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Liquid asset demand','FontSize',10,'interpreter',intep,'fontname',font)
legend([y1a,y1b,y2a,y2b],'Employed in expansion','Unemployed in expansion','Employed in recession','Unemployed in recession')
set(legend,'fontname',font,'interpreter',intep,'FontSize',8,'Location','SouthEast')


xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure7.pdf


% Figure 8
figure(8)
% y1 = plot(fig8.x(:,1),fig8.y(:,1),'Color',[0,0,0],'linewidth',thick);
y2 = plot(fig8.x(:,2),fig8.y(:,2),'-','Color',[0,0,0],'linewidth',thick);
hold on
y3 = plot(fig8.x(:,3),fig8.y(:,3),'-','Color',[0,0,0]+0.65,'linewidth',thick);
xlim([-1,8])
set(gca,'FontSize',8,'fontname',font)
xlabel('Unemployment duration (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Equity holdings','FontSize',10,'interpreter',intep,'fontname',font)
legend([y2,y3],'Cond. on expansion','Cond. on recession')
set(legend,'fontname',font,'interpreter',intep,'Location','northeast','FontSize',8)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure8.pdf

% Figure 9
figure(9)
% y1 = plot(fig9.x(:,1),fig9.y(:,1),'Color',[0,0,0],'linewidth',thick);
y2 = plot(fig9.x(:,2),fig9.y(:,2),'-','Color',[0,0,0],'linewidth',thick);
hold on
y3 = plot(fig9.x(:,3),fig9.y(:,3),'-','Color',[0,0,0]+0.65,'linewidth',thick);
xlim([-1,8])
ylim([0,ceil(max(fig9.y(:)*10))/10+0.05])
set(gca,'FontSize',8,'fontname',font)
xlabel('Unemployment duration (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Liquid asset holdings','FontSize',10,'interpreter',intep,'fontname',font)
legend([y2,y3],'Cond. on expansion','Cond. on recession')
set(legend,'fontname',font,'interpreter',intep,'Location','northeast','FontSize',8)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print -dpdf figure9.pdf

% Figure 10 & 11

IRF_length = 51;
xaxis = 0:IRF_length-1;
for i = 1:length(fig_IRF)
    fig_no = 9+i;
    figure(fig_no)
    subplot(3,2,1)
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,1),'linestyle','-','LineWidth',thin,'color',[0 0 0]+0.65);
    hold on
    plot(xaxis,fig_IRF{i}.het(xaxis+1,1),'linestyle','--','LineWidth',thin,'color',[0 0 0]);
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,3),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
    plot(xaxis,fig_IRF{i}.het(xaxis+1,3),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
    set(gca,'FontSize',8,'fontname',font)
    ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
    title('Productivity (thin) and output','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    subplot(3,2,2)
    y1 = plot(xaxis,fig_IRF{i}.het(xaxis+1,2),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
    hold on
    y2 = plot(xaxis,fig_IRF{i}.rep(xaxis+1,2),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
    set(gca,'FontSize',8,'fontname',font)
    ylabel('Ppt. deviation','FontSize',10,'interpreter',intep,'fontname',font)
    ylim([-3.5,0])
    title('Employment','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)
    legend([y1,y2],'Incompl. markets','Compl. markets')
    set(legend,'fontname',font,'interpreter',intep,'Location','southeast','FontSize',8)


    subplot(3,2,3)
    plot(xaxis,fig_IRF{i}.het(xaxis+1,11),'linestyle','-','LineWidth',thick,'color',[0 0 0]);    
    hold on
    if norm(fig_IRF{i}.rep(xaxis+1,11)-fig_IRF{i}.het(xaxis+1,11))<1e-3
        tempstyle = '--';
    else
        tempstyle = '-';
    end
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,11),'linestyle',tempstyle,'LineWidth',thick,'color',[0 0 0]+0.65);
    set(gca,'FontSize',8,'fontname',font)
    ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
    title('Unit labor costs','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    subplot(3,2,4)
    plot(xaxis,fig_IRF{i}.het(xaxis+1,4),'linestyle','-','LineWidth',thick,'color',[0 0 0]);    
    hold on
    if norm(fig_IRF{i}.rep(xaxis+1,4)-fig_IRF{i}.het(xaxis+1,4))<1e-3
        tempstyle = '--';
    else
        tempstyle = '-';
    end
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,4),'linestyle',tempstyle,'LineWidth',thick,'color',[0 0 0]+0.65);

    set(gca,'FontSize',8,'fontname',font)
    ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
    title('Real wage','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    subplot(3,2,5)
    plot(xaxis,fig_IRF{i}.het(xaxis+1,5),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
    hold on
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,5),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
    set(gca,'FontSize',8,'fontname',font)
    ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
    xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
    title('Asset prices','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    subplot(3,2,6)
    plot(xaxis,fig_IRF{i}.het(xaxis+1,6),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
    hold on
    plot(xaxis,fig_IRF{i}.rep(xaxis+1,6),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
    set(gca,'FontSize',8,'fontname',font)
    xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
    ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
    title('Price level','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    xSize = 18; 
    ySize = 19;

    set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
         ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize-2 ySize-1.5],'PaperPositionMode','auto')

    print(['figure',num2str(fig_no)],'-dpdf')
end

% Figure Accuracy
figure(15)
subplot(1,2,1)
y1 = plot(fig_acc.J(500:600,1),'Color',[0,0,0],'LineWidth',thick);
hold on
y2 = plot(fig_acc.J(500:600,2),'Color',[0,0,0]+0.65,'LineWidth',thick,'LineStyle','--');
hold off
xlim([0,100])
ylim([floor(min(fig_acc.J(:)*10))/10-0.1,ceil(max(fig_acc.J(:)*10))/10])
set(gca,'FontSize',8,'fontname',font)
xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Level','FontSize',10,'interpreter',intep,'fontname',font)
legend([y1 y2],'Market-clearing value','Perceived value')
set(legend,'fontname',font,'interpreter',intep,'Location','SouthWest','FontSize',8)
title('Asset prices','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

subplot(1,2,2)
y1 = plot(fig_acc.P(500:600,1),'Color',[0,0,0],'LineWidth',thick);
hold on
y2 = plot(fig_acc.P(500:600,2),'Color',[0,0,0]+0.65,'LineWidth',thick,'LineStyle','--');
hold off
xlim([0,100])
ylim([floor(min(fig_acc.P(:)*10))/10-0.05,ceil(max(fig_acc.P(:)*10))/10])
set(gca,'FontSize',8,'fontname',font)
xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
set(legend,'fontname',font,'interpreter',intep,'Location','SouthWest','FontSize',8)
title('Price level','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)


xSize = 18; 
ySize = 6.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize-2 ySize+0.5],'PaperPositionMode','auto')

print -dpdf accuracy_hetagent.pdf


% Sustained IRF
figure(18)
thick = 1.6;
thin = 1;
intep = 'tex';
font = 'times';
weight = 'normal';


IRF_length = 21;
xaxis = 0:IRF_length-1;


subplot(3,2,1)
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,1),'linestyle','-','LineWidth',thin,'color',[0 0 0]+0.65);
hold on
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,1),'linestyle','--','LineWidth',thin,'color',[0 0 0]);
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,2),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,2),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,1),'linestyle','--','LineWidth',thin,'color',[0 0 0]);
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,2),'linestyle','--','LineWidth',thick,'color',[0 0 0]);


set(gca,'FontSize',8,'fontname',font)
ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
title('Productivity (thin) and output','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

subplot(3,2,2)
y1 = plot(xaxis,fig_sustainedIRF{1}(xaxis+1,3),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
hold on
y2 = plot(xaxis,fig_sustainedIRF{2}(xaxis+1,3),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);
y3 = plot(xaxis,fig_sustainedIRF{3}(xaxis+1,3),'linestyle','--','LineWidth',thick,'color',[0 0 0]);
set(gca,'FontSize',8,'fontname',font)
ylabel('Ppt. deviation','FontSize',10,'interpreter',intep,'fontname',font)
title('Employment','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)
legend([y1,y2,y3],'Baseline','Constant R','More aggresive')
set(legend,'fontname',font,'interpreter',intep,'Location','NorthEast','FontSize',8)


subplot(3,2,3)
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,4),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
hold on
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,4),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);set(gca,'FontSize',8,'fontname',font)
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,4),'linestyle','--','LineWidth',thick,'color',[0 0 0]);
ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
title('Unit labor costs','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

subplot(3,2,4)
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,5),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
hold on
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,5),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);set(gca,'FontSize',8,'fontname',font)
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,5),'linestyle','--','LineWidth',thick,'color',[0 0 0]);
set(gca,'FontSize',8,'fontname',font)
ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
title('Real wage','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

subplot(3,2,5)
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,11),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
hold on
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,11),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);set(gca,'FontSize',8,'fontname',font)
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,11),'linestyle','--','LineWidth',thick,'color',[0 0 0]);
set(gca,'FontSize',8,'fontname',font)
ylabel('Level','FontSize',10,'interpreter',intep,'fontname',font)
xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
title('Nominal interest rate','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

subplot(3,2,6)
plot(xaxis,fig_sustainedIRF{1}(xaxis+1,7),'linestyle','-','LineWidth',thick,'color',[0 0 0]);
hold on
plot(xaxis,fig_sustainedIRF{2}(xaxis+1,7),'linestyle','-','LineWidth',thick,'color',[0 0 0]+0.65);set(gca,'FontSize',8,'fontname',font)
plot(xaxis,fig_sustainedIRF{3}(xaxis+1,7),'linestyle','--','LineWidth',thick,'color',[0 0 0]);
set(gca,'FontSize',8,'fontname',font)
xlabel('Time (quarters)','FontSize',10,'interpreter',intep,'fontname',font)
ylabel('Log deviation','FontSize',10,'interpreter',intep,'fontname',font)
title('Price level','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)

    xSize = 18; 
    ySize = 19;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize-2 ySize-1.5],'PaperPositionMode','auto')

print('sustainedIRF_3','-dpdf')




% Figure UI
figure(19)

thick = 1.6;
thin = 1;

intep = 'tex';
font = 'times';
weight = 'normal';
y1 = plot(figUI1_1_PLT.x(:,1),figUI1_1_PLT.y(:,1),'linestyle','-','linewidth',thick,'Color',[0,0,0]+0.65);
hold on
y2 = plot(figUI1_1_PLT.x(:,1),figUI1_1_PLT.y(:,2),'linestyle','-','linewidth',thick,'Color',[0,0,0]);
y3 = plot(figUI1_1_PLT.x(:,1),figUI1_1_PLT.y(:,3),'linestyle','-','linewidth',thin,'Color',[0,0,0]);
y4 = plot(figUI1_1_PLT.x(:,1),figUI1_1_PLT.y(:,4),'linestyle','--','linewidth',thick,'Color',[0,0,0]);
hold off
xlim([0.3,0.7])
ylim([0.85,0.92])
legend1 = legend([y4,y2,y1,y3],'Without aggregate risk','Expansion','Recession','Unconditional');
set(legend1,'fontname',font,'interpreter',intep,'location','SouthEast','FontSize',8)
set(gca,'FontSize',8,'fontname',font)
ylabel('Employment level','FontSize',10,'interpreter',intep,'fontname',font)
title('\omega_P=0.7, constant nominal interest rate','interpreter',intep,'fontsize',10,'fontname',font,'fontweight',weight)
xlabel('Replacement rate, \mu','FontSize',10,'interpreter',intep,'fontname',font)

xSize = 12; 
ySize = 8.5;

set(gcf,'Units','centimeters','Position',[0 0 xSize ySize],'PaperUnits','centimeters' ...
     ,'PaperPosition',[0 0 xSize ySize],'PaperSize',[xSize ySize],'PaperPositionMode','auto')
 
print ('-dpdf','figure_UI1_PLT.pdf')
