function struct_het = repagent(struct_het,beta)
% adds representative agent results corresponding to the parameters in the
% heterogenous agent economy in struct_het
%
% INPUTS: 
%  struct_het: structure with parameters of heterogeneous agent economy
%  (params) and sim_results to get realization of productivity shock
%  beta: value for beta to be used in rep agent solution
%
% OUTPUT:
% struct_het: adds field rep with results from representative agent economy
%  params: structure parameters used for rep agent and grid for employment
%  sim_results: simulated time series with same variables as het agent
%  Np: policy function for aggregate employment next period
%  P: policy function for price level
%  IRF: impulse response functions analogous to het agent


try 
    rep=struct_het.rep; % take existing rep agent solution as initial guess
end

rep.params = struct_het.params;
% adjust beta to value supplied
rep.params.beta = beta;
rep.params.N = linspace(0.83,0.93,100); % grid for employment

sim_p = zeros(size(struct_het.sim_results,1),1); % productivity state in simulation
for i=1:length(rep.params.z)
    sim_p(struct_het.sim_results(:,1)==rep.params.z(i))=i; % match productivity state with results from het agent simulation
end

try
    % solve rep agent, if initial guess for Np and P exist
    [rep.sim_results,rep.Np,rep.P,~,~,rep.IRF] = repagent_simulation(rep.params,sim_p,rep.Np,rep.P);
catch
    % solve without initial guesses
    [rep.sim_results,rep.Np,rep.P,~,~,rep.IRF] = repagent_simulation(rep.params,sim_p);
end
struct_het.rep = rep;