function err = solve_PLT(targets,law_weight,params,x,options)
% function can be used to solve for the coefficients of the aggregate laws
% and to set parameter value of interest rate rule (curvature with respect
% to P)
%
% INPUTS:
%  targets:
%   field PLT with target for interest rate rule coefficient
%  law_weight: weights for coefficients of aggregate law of motion
%  params: structure with parameters
%  x: entries 1-6*z_no are coefficients of aggregate laws, such that
%       coeffs=x(1:6*z_no).*law_weight
%     entry 6*z_no+1 is value for interest rate rule coefficient IR_coeff(2)
%  options: structure with options needed to solve heterogeneous agents
%  with aggregate risk
%
% OUTPUT:
%  err: entries 1-6*z_no are deviations between guess for aggregate laws and
%        estimated new aggregate laws
%       entry 6*z_no+1 10*deviation of IR coefficient from target

coeffs=x(1:12).*law_weight;
params.IR_coeff(2) = x(13); % set interest rate rule coefficient

try
    % solve problem with aggregate risk and find deviation of guess for
    % aggregate laws from estimated new aggregate laws.
    dev = het_aggrisk(params,coeffs,options);
    err(1:12) = dev;
    err(13) = 10*(params.IR_coeff(2)-targets.PLT);
catch
    err=NaN*ones(1,13);  % return NaN, if simulation breaks down
end

