function err = solve_mu(targets,law_weight,params,x,options)
% function can be used to solve for the coefficients of the aggregate laws
% and to set value of unemployment insurance. Optionally, also set constant
% in wage equation to match bargaining power
%
% INPUTS:
%  targets:
%   field mu with target value for unemployment insurance
%   field bp with target value for bargaining power (optional)
%  law_weight: weights for coefficients of aggregate law of motion
%  params: structure with parameters
%  x: entries 1-6*z_no are coefficients of aggregate laws, such that
%       coeffs=x(1:6*z_no).*law_weight
%     entry 6*z_no+1 is unemployment insurance mu
%     entry 6*z_no+2 (optional) is value of wage coefficient omega_0
%  options: structure with options needed to solve heterogeneous agents
%  with aggregate risk
%
% OUTPUT:
%  err: entries 1-6*z_no are deviations between guess for aggregate laws and
%        estimated new aggregate laws
%       entry 6*z_no+1 10*deviation of unemployment insurance coefficient from target
%       entry 6*z_no+2 10*deviation of average bargaining power from
%       target - calculated, if omega_0 is provided

coeffs=x(1:12).*law_weight;
params.mu = x(13); % set unemployment insurance

if length(x) > 13 % also adjust wage coefficient and compute bargaining power
    params.w_coeff(1) = x(14);
end

try
    if length(x) > 13
        dev = het_aggrisk(params,coeffs,options);
        err(14) = 10*(mean(sim_details.bpower((options.sim_drop+1):end))-targets.bp);
    else
        dev = het_aggrisk(params,coeffs,options);
    end
    err(1:12) = dev;
    err(13) = 10*(params.mu-targets.mu);
catch
    err=NaN*x'; % return NaN, if simulation breaks down
end

