function err = solve_wP(targets,law_weight,params,x,options)
% function can be used to solve for the coefficients of the aggregate laws
% and to set nominal wage stickiness
%
% INPUTS:
%  targets:
%   field wP with target for wage coefficient omega_P
%  law_weight: weights for coefficients of aggregate law of motion
%  params: structure with parameters
%  x: entries 1-6*z_no are coefficients of aggregate laws, such that
%       coeffs=x(1:6*z_no).*law_weight
%     entry 6*z_no+1 is value for wage coefficient w_coeff(3)
%  options: structure with options needed to solve heterogeneous agents
%  with aggregate risk
%
% OUTPUT:
%  err: entries 1-6*z_no are deviations between guess for aggregate laws and
%        estimated new aggregate laws
%       entry 6*z_no+1 10*deviation of wage coefficient from target

coeffs=x(1:12).*law_weight;
params.w_coeff(3) = x(13); % set wage coefficient

try
    % solve problem with aggregate risk and find deviation of guess for
    % aggregate laws from estimated new aggregate laws.    
    dev = het_aggrisk(params,coeffs,options);
    err(1:12) = dev;
    err(13) = 10*(params.w_coeff(3)-targets.wP);
catch
    err=NaN*ones(13,1);  % return NaN, if simulation breaks down
end

