function IRF =  sustainedIRF(params,coeffs,options,trendinflation)
% Computes impulse-response function when economy starts at end of boom
% and stays in recession for 20 periods.
%
% INPUTS:
%  params: structure with parameters
%  coeffs: coefficients of aggregate laws
%  options: structure with options needed to solve heterogeneous agents
%  with aggregate risk
%  trendinflation: quarterly inflation rate to be added to nominal interest
%  rate
%
% OUTPUT:
%  IRF: impulse-response functions in columns:
%       productivity
%       output
%       employment (ppt-deviation)
%       real unit labor costs
%       real wage
%       real price of equity
%       price level
%       unemployment rate (ppt)
%       expected real return on bonds (ppt)
%       level of annualized nominal interest rate after adding trend inflation

[dev,~,sim_details] = het_aggrisk(params,coeffs,options); % run to get distribution
if norm(dev)>1e-6
    disp(['Warning: norm of aggregate law deviation:', num2str(norm(dev))])
end

comp_options = options;
comp_options.sim_p = ones(21,1); % 1 period in boom then 20 periods in recession
comp_options.sim_p(1) = 2;
comp_options.sim_no = length(comp_options.sim_p);
comp_options.sim_drop = 0; % don't drop any periods

comp_plast = 2; % distribution from end of boom
comp_options.init_dist = sim_details.store_dist{comp_plast};
comp_options.init_q = sim_details.store_sim_q{comp_plast};
comp_options.init_b = sim_details.store_sim_b{comp_plast};
[~,sim_results] = het_aggrisk(params,coeffs,comp_options); % simulate economy

% productivity, output, employment, unit labor costs, real wage, asset
% prices, price level, unemployment rate, real interest rate, nominal
% interest rate
IRF_vars = {sim_results(:,1),sim_results(:,1).*sim_results(:,2),sim_results(:,2),sim_results(:,8)./sim_results(:,1),sim_results(:,8),sim_results(:,3),sim_results(:,5),1-sim_results(:,2),sim_results(:,13),(1+trendinflation)./sim_results(:,10)-1};
IRF_devs = {'log','log','ppt','log','log','log','log','ppt','ppt','ppt'}; % deviation of variables to be calculated (log or ppt)

for k=1:length(IRF_vars) % calculate deviations
    switch IRF_devs{k}
        case 'log'
            IRF(:,k) = log(IRF_vars{k}/IRF_vars{k}(1));
        case 'ppt'
            IRF(:,k) = (IRF_vars{k}-IRF_vars{k}(1))*100;
    end
end

IRF(:,11) = ((1+trendinflation)./sim_results(:,10)).^4-1; % annualized nominal interest rate after adding trend inflation